@@ -2,7 +2,10 @@ import datetime
 from functools import wraps
 
 from django.conf import settings
+from django.contrib.auth import authenticate, login
+from django.contrib.sessions.middleware import SessionMiddleware
 from django.core.urlresolvers import reverse
+from django.db import models
 from django.http import HttpRequest
 from django.contrib.auth import SESSION_KEY, BACKEND_SESSION_KEY
 from django.contrib.auth import authenticate
@@ -10,6 +13,7 @@ from django.contrib.auth import login
 from django.contrib.auth.forms import UserCreationForm
 from django.contrib.auth.models import AnonymousUser
 from django.contrib.auth.models import User
+from django.contrib.auth.models import UserManager
 from django.contrib.sessions.middleware import SessionMiddleware
 from django.contrib.sessions.models import Session
 from django.test import TestCase
@@ -78,6 +82,11 @@ def no_lazysignup(func):
     return wraps(func)(wrapped)
 
 
+class CustomUser(User):
+    objects = UserManager()
+    my_custom_field = models.CharField(max_length=50, blank=True, null=True)
+
+
 class LazyTestCase(TestCase):
 
     urls = 'lazysignup.test_urls'
@@ -398,5 +407,26 @@ class LazyTestCase(TestCase):
         form = GoodUserCreationForm(instance=user)
         self.assertRaises(NotLazyError, LazyUser.objects.convert, form)
 
+    def testUserField(self):
+        # We should find that our LAZSIGNUP_CUSTOM_USER setting has been
+        # respected.
+        self.assertEqual(CustomUser, LazyUser.get_user_class())
 
+    def testAuthenticatedUserClass(self):
+        # We should find that the class of request.user is that of
+        # LAZSIGNUP_CUSTOM_USER
+        request = HttpRequest()
+        request.user = AnonymousUser()
+        SessionMiddleware().process_request(request)
+        lazy_view(request)
+        self.assertEqual(CustomUser, type(request.user))
+
+    def testBackendGetUserCustomClass(self):
+        # The get_user method on the backend should also return instances of
+        # the custom user class.
+        lazy_view(self.request)
+        backend = LazySignupBackend()
+        user_class = LazyUser.get_user_class()
+        pk = user_class.objects.all()[0].pk
+        self.assertEqual(user_class, type(backend.get_user(pk)))
 
